package com.phm.manage.service;

import com.phm.manage.domain.DeepIsolationModel;

import java.util.List;

/**
 * 深度隔离模型Service接口
 *
 * @author phm
 * @date 2023-08-22
 */
public interface IDeepIsolationModelService {
    /**
     * 查询深度隔离模型
     *
     * @param id 深度隔离模型主键
     * @return 深度隔离模型
     */
    public DeepIsolationModel selectDeepIsolationModelById(Long id);

    /**
     * 查询深度隔离模型列表
     *
     * @param deepIsolationModel 深度隔离模型
     * @return 深度隔离模型集合
     */
    public List<DeepIsolationModel> selectDeepIsolationModelList(DeepIsolationModel deepIsolationModel);

    /**
     * 新增深度隔离模型
     *
     * @param deepIsolationModel 深度隔离模型
     * @return 结果
     */
    public int insertDeepIsolationModel(DeepIsolationModel deepIsolationModel);

    /**
     * 修改深度隔离模型
     *
     * @param deepIsolationModel 深度隔离模型
     * @return 结果
     */
    public int updateDeepIsolationModel(DeepIsolationModel deepIsolationModel);

    /**
     * 批量删除深度隔离模型
     *
     * @param ids 需要删除的深度隔离模型主键集合
     * @return 结果
     */
    public int deleteDeepIsolationModelByIds(Long[] ids);

    /**
     * 删除深度隔离模型信息
     *
     * @param id 深度隔离模型主键
     * @return 结果
     */
    public int deleteDeepIsolationModelById(Long id);
}
